@@ -37,10 +37,13 @@
  * ***** END LICENSE BLOCK ***** */
 package org.ietf.ldap;
 
-import java.util.*;
-import java.io.*;
 import java.net.MalformedURLException;
-import org.ietf.ldap.factory.*;
+import java.util.Enumeration;
+import java.util.NoSuchElementException;
+import java.util.StringTokenizer;
+import java.util.Vector;
+
+import org.ietf.ldap.factory.JSSESocketFactory;
 
 /**
  * Represents an LDAP URL. The complete specification for LDAP URLs is in
@@ -103,20 +106,20 @@ public class LDAPUrl implements java.io.Serializable {
     private String _hostName;
     private int _portNumber;
     private String _DN;
-    private Vector _attributes;
+    private Vector<String> _attributes;
     private int _scope;
     private String _filter;
     private String _URL;
     private boolean _secure;
     private String[] _extensions;
-    
+
     private static LDAPSocketFactory _factory;
 
     /**
      * The default port number for secure LDAP connections.
      * @see org.ietf.ldap.LDAPUrl#LDAPUrl(String, int, String, String[], int,
      * String, String[])
-     */    
+     */
     public static final int DEFAULT_SECURE_PORT = 636;
 
     /**
@@ -159,14 +162,14 @@ public class LDAPUrl implements java.io.Serializable {
      * @param DN distinguished name of the object
      * @param attributes list of the attributes to return. Use null for "all
      * attributes."
-     * @param scope depth of the search (in DN namespace). Use one of the LDAPConnection scopes: 
+     * @param scope depth of the search (in DN namespace). Use one of the LDAPConnection scopes:
      * SCOPE_BASE, SCOPE_ONE, or SCOPE_SUB.
      * @param filter LDAP filter string (as defined in RFC 1558). Use null for
      * no filter (this effectively makes the URL reference a single object).
-     * @param extensions LDAP URL extensions specified; may be null or 
-     * empty. Each extension is a type=value expression. 
-     * The =value part MAY be omitted. The expression 
-     * may be prefixed with '!' if it is mandatory for 
+     * @param extensions LDAP URL extensions specified; may be null or
+     * empty. Each extension is a type=value expression.
+     * The =value part MAY be omitted. The expression
+     * may be prefixed with '!' if it is mandatory for
      * evaluation of the URL.
      */
     public LDAPUrl( String host,
@@ -178,7 +181,7 @@ public class LDAPUrl implements java.io.Serializable {
                     String[] extensions ) {
 
         if ( attributes != null ) {
-            Vector list = new Vector();
+            Vector<String> list = new Vector<>();
             for ( int k = 0; k < attributes.length; k++ ) {
                 list.addElement(attributes[k]);
             }
@@ -268,10 +271,10 @@ public class LDAPUrl implements java.io.Serializable {
             return new String[0];
         } else {
             String[] attrNames = new String[_attributes.size()];
-            Enumeration attrs = getAttributes();
+            Enumeration<String> attrs = getAttributes();
             int i = 0;
             while ( attrs.hasMoreElements() ) {
-                attrNames[i++] = (String)attrs.nextElement();
+                attrNames[i++] = attrs.nextElement();
             }
             return attrNames;
         }
@@ -282,7 +285,7 @@ public class LDAPUrl implements java.io.Serializable {
      * for "every attribute"
      * @return enumeration of attributes.
      */
-    public Enumeration getAttributes() {
+    public Enumeration<String> getAttributes() {
         if ( _attributes == null ) {
             return null;
         } else {
@@ -371,7 +374,7 @@ public class LDAPUrl implements java.io.Serializable {
             // the default one.
             try {
                 //  First try iPlanet JSSSocketFactory
-                Class c = Class.forName("org.ietf.ldap.factory.JSSSocketFactory");
+                Class<?> c = Class.forName("org.ietf.ldap.factory.JSSSocketFactory");
                 _factory = (LDAPSocketFactory) c.newInstance();
             }
             catch (Throwable e) {
@@ -461,13 +464,13 @@ public class LDAPUrl implements java.io.Serializable {
             if (!currentToken.equals("/")) {
                 throw new MalformedURLException ();
             }
-        
+
             currentToken = urlParser.nextToken();
         }
         catch (NoSuchElementException e) {
             throw new MalformedURLException ();
         }
-            
+
         // host-port
         if (currentToken.equals ("/")) {
             _hostName = null;
@@ -493,7 +496,7 @@ public class LDAPUrl implements java.io.Serializable {
                 } catch (NoSuchElementException ex) {
                     throw new MalformedURLException ("No port number");
                 }
-                    
+
                 if (urlParser.countTokens() == 0) {
                     return;
                 }
@@ -520,17 +523,17 @@ public class LDAPUrl implements java.io.Serializable {
         }
         else if (_DN.equals("/")) {
             throw new MalformedURLException ();
-        }            
-            
+        }
+
         // attribute
         if (!urlParser.hasMoreTokens ()) {
             return;
-        }        
+        }
         str = readNextConstruct(urlParser);
         if (!str.equals("?")) {
             StringTokenizer attributeParser = new
                 StringTokenizer (decode(str), ", ");
-            _attributes = new Vector ();
+            _attributes = new Vector<String>();
 
             while (attributeParser.hasMoreTokens()) {
                 _attributes.addElement (attributeParser.nextToken());
@@ -564,8 +567,8 @@ public class LDAPUrl implements java.io.Serializable {
         if (urlParser.hasMoreTokens()) {
             throw new MalformedURLException();
         }
-    }    
-    
+    }
+
     private void checkBalancedParentheses( String filter )
         throws MalformedURLException {
         int parenCnt =0;
@@ -583,19 +586,19 @@ public class LDAPUrl implements java.io.Serializable {
                 }
             }
         }
-        
+
         if (parenCnt != 0) {
             throw new MalformedURLException("Unbalanced filter parentheses");
         }
     }
-        
+
     /**
      * Initializes URL object.
      */
     private void initialize( String host,
                              int port,
                              String DN,
-                             Enumeration attributes,
+                             Enumeration<String> attributes,
                              int scope,
                              String filter,
                              String[] extensions ) {
@@ -608,7 +611,7 @@ public class LDAPUrl implements java.io.Serializable {
         _extensions = extensions;
 
         if (attributes != null) {
-            _attributes = new Vector ();
+            _attributes = new Vector<String>();
             while (attributes.hasMoreElements()) {
                 _attributes.addElement (attributes.nextElement());
             }
@@ -628,7 +631,7 @@ public class LDAPUrl implements java.io.Serializable {
 
         if (attributes != null) {
             url.append ('?');
-            Enumeration attrList = _attributes.elements();
+            Enumeration<String> attrList = _attributes.elements();
             boolean firstElement = true;
 
             while (attrList.hasMoreElements()) {
@@ -637,7 +640,7 @@ public class LDAPUrl implements java.io.Serializable {
                 else
                     firstElement = false;
 
-                url.append ((String)attrList.nextElement());
+                url.append (attrList.nextElement());
             }
         }
 
@@ -687,7 +690,7 @@ public class LDAPUrl implements java.io.Serializable {
                         throw new MalformedURLException();
                     }
                 }
-                
+
                 return tkn;
             }
         } catch (NoSuchElementException e) {
